@@ -70,10 +70,10 @@ class ThetaService(object):
         end_block = end_block_bounds[0]
 
         # Theta do not support index 0
-        if start_block == 0:
-            start_block = 1
-        if end_block == 0:
-            end_block = 1
+        # if start_block == 0:
+        #     start_block = 1
+        # if end_block == 0:
+        #     end_block = 1
 
         return start_block, end_block
 
@@ -93,7 +93,6 @@ class BlockTimestampGraph(object):
 
     def get_last_point(self):
 #        return block_to_point(self._theta_provider.eth.getBlock('latest'))  
-        #return Point(2184972, 1596678993) #TODO: query status to get latest
         status_rpc = generate_get_status_json_rpc()
         response = self._theta_provider.make_request(json.dumps(status_rpc))
         result = rpc_response_to_result(response)
@@ -104,7 +103,7 @@ class BlockTimestampGraph(object):
 #        return block_to_point(self._theta_provider.eth.getBlock(x))
         response = self._theta_provider.make_request(
             json.dumps(generate_get_blocks_by_range_json_rpc(x, x, False))
-            )
+        )
         results = rpc_response_to_result(response)
         blocks = [self.block_mapper.json_dict_to_block(result) for result in results]
         if (len(blocks) == 0) :
